import{_ as f}from"./AbstraLogo.vue_vue_type_script_setup_true_lang.b5d6685a.js";import{B as m}from"./BaseLayout.d1e9245a.js";import{d as l,ae as y,c1 as v,_ as u,aZ as g,a_ as b,o as _,a5 as h,e as r,a6 as n,eb as w,e5 as S,k,a as L,b as s,f as i,u as x}from"./jwt-decode.esm.611ae497.js";import{u as B}from"./editor.771a972f.js";import{A as I}from"./index.c36bb044.js";import"./Logo.e83946ea.js";import"./workspaceStore.5c88cf6a.js";import"./userStore.2632fa83.js";import"./url.b17313e6.js";import"./colorHelpers.729d7a40.js";import"./index.00bda673.js";import"./linters.46cf69bd.js";import"./asyncComputed.97ac15a2.js";import"./constants.60843cd3.js";import"./index.18f988e9.js";import"./Breadcrumb.b1d16b92.js";import"./index.6b334162.js";import"./index.c85af12a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="9e0f88de-eab7-4687-8512-2a39c4faeb40",e._sentryDebugIdIdentifier="sentry-dbid-9e0f88de-eab7-4687-8512-2a39c4faeb40")}catch{}})();const $=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"#ea576a"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const o=y({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...v(o)}}});const P={class:"v-spinner"};function D(e,o,a,d,c,p){return g((_(),h("div",P,[r("div",{class:"v-beat v-beat-odd",style:n(e.spinnerStyle)},null,4),r("div",{class:"v-beat v-beat-even",style:n(e.spinnerStyle)},null,4),r("div",{class:"v-beat v-beat-odd",style:n(e.spinnerStyle)},null,4)],512)),[[b,e.loading]])}const R=u($,[["render",D],["__scopeId","data-v-06538001"]]),j={class:"content"},z=l({__name:"ProjectLogin",setup(e){const o=w(),a=S(),d=B();function c(){const t=new URL(location.href);t.searchParams.delete("api-key"),a.replace(t.pathname+t.search)}function p(){const t=o.query["api-key"];if(typeof t=="string")return t}return k(async()=>{const t=p();if(!t){a.push({name:"error"});return}await d.createLogin(t).then(c),a.push({name:"editor"})}),(t,A)=>(_(),L(m,null,{navbar:s(()=>[i(x(I),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{title:s(()=>[i(f)]),_:1})]),content:s(()=>[r("div",j,[i(R)])]),_:1}))}});const Y=u(z,[["__scopeId","data-v-d2a19803"]]);export{Y as default};
//# sourceMappingURL=ProjectLogin.3aab045f.js.map
