import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.70fb2375.js";import{d as i,eb as s,a,u as m,o as d}from"./jwt-decode.esm.611ae497.js";import"./router.1f8c25cb.js";import"./index.18f988e9.js";import"./fetch.bc00bb7a.js";import"./record.88233bcd.js";import"./SaveButton.b04687f7.js";import"./ExclamationCircleOutlined.55a99fcd.js";import"./CrudView.78833c51.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.78b2e715.js";import"./constants.60843cd3.js";import"./url.b17313e6.js";import"./PhDotsThreeVertical.vue.f70cea78.js";import"./index.c85af12a.js";import"./asyncComputed.97ac15a2.js";import"./polling.06d43d12.js";import"./omniChatStore.9863f4c9.js";import"./uuid.8943c176.js";import"./PhCopySimple.vue.ae2a0dda.js";import"./PhPencil.vue.d787cc70.js";import"./index.3369e1c3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="e9769958-a248-4846-aedd-2eee9f7333ad",e._sentryDebugIdIdentifier="sentry-dbid-e9769958-a248-4846-aedd-2eee9f7333ad")}catch{}})();const z=i({__name:"EnvVars",setup(e){const r=s().params.projectId,t=new p(r);return(c,f)=>(d(),a(n,{"env-var-repository":m(t),mode:"console"},null,8,["env-var-repository"]))}});export{z as default};
//# sourceMappingURL=EnvVars.499ec26c.js.map
