import{O as r}from"./index.00bda673.js";import{d as l,k as i,a5 as u,f as t,b as n,u as o,o as c,g as s,A as f,da as b}from"./jwt-decode.esm.611ae497.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="be8df217-4b97-4571-9446-0b3d7ca0a818",e._sentryDebugIdIdentifier="sentry-dbid-be8df217-4b97-4571-9446-0b3d7ca0a818")}catch{}})();const p=l({__name:"OidcLoginCallback",setup(e){return i(async()=>{await new r().loginCallback()}),(a,d)=>(c(),u("div",null,[t(o(f),null,{default:n(()=>[s("You're authenticated")]),_:1}),t(o(b),null,{default:n(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{p as default};
//# sourceMappingURL=OidcLoginCallback.488ca2a1.js.map
