import{L as d}from"./jwt-decode.esm.611ae497.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="88295aa8-0ca1-41ce-9caf-5f890c326afc",e._sentryDebugIdIdentifier="sentry-dbid-88295aa8-0ca1-41ce-9caf-5f890c326afc")}catch{}})();function p(e){return d.string().email().safeParse(e).success}function w(e){return e.charAt(0).toUpperCase()+e.slice(1)}function h(e,r,a=!1,n=!0,s=!1,t=!0){const o=(n?e.toLocaleLowerCase():e).normalize("NFD").replace(/[\u0300-\u036f]/g,""),f=`a-zA-Z0-9${s?"/":""}${t?"-":""}`,c=new RegExp(`[^${f}]`,"g"),l=o.replace(c,"_"),u=a?l:l.replace(/_+/g,"_");return r?u:u.replace(/_$/,"")}function m(e){var t;const a=e.toLocaleLowerCase().trim().normalize("NFD").replace(/[\u0300-\u036f]/g,""),n=/[a-z0-9]+/g,s=a.match(n);return(t=s==null?void 0:s.join("-"))!=null?t:""}function y(e,r){if(e.length===0||r.length===0)return!1;const a=e.toLowerCase(),n=r.toLowerCase();return a.split("").reduce((t,i)=>{var f;if(t===!1)return!1;const o=(f=t[t.length-1])!=null?f:null;if(o===null){const c=n.indexOf(i);return c===-1?!1:[c]}else{const l=n.slice(o+1).indexOf(i);return l===-1?!1:[...t,o+1+l]}},[])}export{h as a,w as c,y as f,p as i,m as n};
//# sourceMappingURL=string.12f8032a.js.map
