import{y as n,z as r,B as o,C as c,P as f,D as d,E as p,F as m,G as a,H as u,I as g,J as y,K as l}from"./jwt-decode.esm.611ae497.js";import{a as b,b as i}from"./workspaceStore.5c88cf6a.js";import{s as w}from"./index.00bda673.js";import{_ as h}from"./App.vue_vue_type_style_index_0_lang.3921dda6.js";import"./userStore.2632fa83.js";import"./url.b17313e6.js";import"./colorHelpers.729d7a40.js";import"./PlayerConfigProvider.171bf305.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[s]="03edf345-c70f-4c19-9518-3f2191f7f346",t._sentryDebugIdIdentifier="sentry-dbid-03edf345-c70f-4c19-9518-3f2191f7f346")}catch{}})();class I{static init(){setInterval(()=>{fetch("/_healthcheck").catch(()=>{})},20*1e3)}}(async()=>{await w();const t=await b(),s=n(),e=r({render:()=>u(h)});o.init(),c(e,i,t),I.init(),e.use(i),e.use(s),e.use(f),e.mount("#app"),e.component("VSelect",d),e.component("Markdown",p),e.component("Message",m),a(e,g),a(e,y),a(e,l)})();
//# sourceMappingURL=player.63b74a06.js.map
