import{P as m}from"./PlayerNavbar.526fab6f.js";import{d as g,e5 as h,eb as i,r as b,c as y,m as k,a5 as v,u as n,a as w,h as L,e as C,f as I,o as c,_ as N}from"./jwt-decode.esm.611ae497.js";import{u as V}from"./workspaceStore.5c88cf6a.js";import"./userStore.2632fa83.js";import"./index.00bda673.js";import"./metadata.72772346.js";import"./PhUserList.vue.1da93bbd.js";import"./PhWebhooksLogo.vue.872d4c72.js";import"./LoadingOutlined.9851c13d.js";import"./PhSignOut.vue.a4fe2185.js";import"./index.6b334162.js";import"./url.b17313e6.js";import"./colorHelpers.729d7a40.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="b28d164f-9706-427a-a992-bcf5d60bffaf",o._sentryDebugIdIdentifier="sentry-dbid-b28d164f-9706-427a-a992-bcf5d60bffaf")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(o){const e=h(),t=V(),d=i().path,a=b(null),u=async({path:r,id:s})=>{a.value=s,await e.push({path:`/${r}`}),a.value=null},p=()=>{e.push({name:"playerLogin"})},l=()=>{e.push({name:"playerLogin"})},f=y(()=>!!i().meta.hideLogin);return(r,s)=>{const _=k("RouterView");return c(),v("div",x,[n(t).state.workspace?(c(),w(m,{key:0,"current-path":n(d),"hide-login":f.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:u,onLoginClick:l,onLogoutClick:p},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(_)])])}}});const H=N(D,[["__scopeId","data-v-f095bece"]]);export{H as default};
//# sourceMappingURL=Main.9732085e.js.map
