import{X as c,dJ as s,dK as i}from"./jwt-decode.esm.611ae497.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="0aefdf8b-9cb5-42b4-9c6d-a6d168f7e8da",e._sentryDebugIdIdentifier="sentry-dbid-0aefdf8b-9cb5-42b4-9c6d-a6d168f7e8da")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:r,YearPicker:f,TimePicker:b,QuarterPicker:a,RangePicker:d}=s(i),u=c(n,{WeekPicker:t,MonthPicker:r,YearPicker:f,RangePicker:d,TimePicker:b,QuarterPicker:a,install:e=>(e.component(n.name,n),e.component(d.name,d),e.component(r.name,r),e.component(t.name,t),e.component(a.name,a),e)});export{u as D,r as M,a as Q,d as R,t as W};
//# sourceMappingURL=dayjs.3a6ced6e.js.map
