import"./jwt-decode.esm.611ae497.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="af98a146-1134-4731-ac47-cfc1641f1963",e._sentryDebugIdIdentifier="sentry-dbid-af98a146-1134-4731-ac47-cfc1641f1963")}catch{}})();const f=e=>{try{return new URL(e),!0}catch{return!1}},o=(e,r)=>{if(!Object.keys(r).length)return e;const t=new URL(e),n=new URLSearchParams(t.search);return Object.entries(r).forEach(([a,s])=>{t.searchParams.delete(a),n.set(a,s)}),`${t.origin}${t.pathname}?${n.toString()}`};export{f as i,o as m};
//# sourceMappingURL=url.b17313e6.js.map
