import{_ as f}from"./Login.vue_vue_type_script_setup_true_lang.1cd9267a.js";import{d as l,e5 as m,eb as b,a5 as g,f as y,u as a,o as w,_ as k}from"./jwt-decode.esm.611ae497.js";import{u as h}from"./workspaceStore.5c88cf6a.js";import"./index.00bda673.js";import"./CircularLoading.f56438b2.js";import"./Logo.e83946ea.js";import"./string.12f8032a.js";import"./index.3369e1c3.js";import"./userStore.2632fa83.js";import"./url.b17313e6.js";import"./colorHelpers.729d7a40.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="b91bf57c-570b-4d7c-91cb-2949f99fe8d6",e._sentryDebugIdIdentifier="sentry-dbid-b91bf57c-570b-4d7c-91cb-2949f99fe8d6")}catch{}})();const v={class:"runner"},I=l({__name:"Login",setup(e){const o=m(),t=b(),r=h(),_=async()=>{const{redirect:s,...n}=t.query;if(s){await o.push({path:s,query:n,params:t.params});return}o.push({name:"playerHome",query:n})};return(s,n)=>{var c,d,p,u,i;return w(),g("div",v,[y(f,{"logo-url":(d=(c=a(r).state.workspace)==null?void 0:c.logoUrl)!=null?d:void 0,"brand-name":(p=a(r).state.workspace)==null?void 0:p.brandName,locale:(i=(u=a(r).state.workspace)==null?void 0:u.language)!=null?i:"en",onDone:_},null,8,["logo-url","brand-name","locale"])])}}});const U=k(I,[["__scopeId","data-v-12c690e1"]]);export{U as default};
//# sourceMappingURL=Login.d7667a41.js.map
