import{u as r}from"./userStore.2632fa83.js";import{W as n}from"./PlayerConfigProvider.171bf305.js";import{u as c}from"./workspaceStore.5c88cf6a.js";import{d as i,w as p,m as u,u as o,a as f,b as d,h as l,o as m,f as _}from"./jwt-decode.esm.611ae497.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="4b5b446e-ee97-41b6-ba49-986c5e388bb6",t._sentryDebugIdIdentifier="sentry-dbid-4b5b446e-ee97-41b6-ba49-986c5e388bb6")}catch{}})();const v=i({__name:"App",setup(t){const a=r(),e=c();return e.actions.fetch(),p(()=>a.jwt,e.actions.fetch),(b,w)=>{const s=u("RouterView");return o(e).state.workspace?(m(),f(n,{key:0,"main-color":o(e).state.workspace.mainColor,background:o(e).state.workspace.theme,"font-family":o(e).state.workspace.fontFamily,locale:o(e).state.workspace.language},{default:d(()=>[_(s,{style:{height:"100vh",width:"100%"}})]),_:1},8,["main-color","background","font-family","locale"])):l("",!0)}}});export{v as _};
//# sourceMappingURL=App.vue_vue_type_style_index_0_lang.3921dda6.js.map
