import"./jwt-decode.esm.611ae497.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="5d6873cc-4fd5-4eca-be23-2203eb218e0e",e._sentryDebugIdIdentifier="sentry-dbid-5d6873cc-4fd5-4eca-be23-2203eb218e0e")}catch{}})();const s={HOMEPAGE:{}.VITE_HOMEPAGE_URL||"https://abstra.io",DOCS:{}.VITE_DOCS_URL||"https://abstra.io/docs",CLOUD:{}.VITE_CONSOLE_URL||"https://cloud.abstra.io",GITHUB:{}.VITE_GITHUB_URL||"https://github.com/abstra-app/abstra-lib"},n=e=>{if(!e)return s.DOCS;const t=e.startsWith("/")?e.slice(1):e;return`${s.DOCS}/${t}`};export{s as A,n as b};
//# sourceMappingURL=constants.60843cd3.js.map
