import{O as r}from"./index.00bda673.js";import{d as l,k as c,a5 as u,f as a,b as d,u as n,o as i,g as o,A as f,da as _}from"./jwt-decode.esm.611ae497.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="192d88d8-d6cc-4bf0-958d-affe35cd327a",e._sentryDebugIdIdentifier="sentry-dbid-192d88d8-d6cc-4bf0-958d-affe35cd327a")}catch{}})();const p=l({__name:"OidcLogoutCallback",setup(e){return c(async()=>{await new r().logoutCallback()}),(t,s)=>(i(),u("div",null,[a(n(f),null,{default:d(()=>[o("You're authenticated")]),_:1}),a(n(_),null,{default:d(()=>[o(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{p as default};
//# sourceMappingURL=OidcLogoutCallback.32654f13.js.map
