import{A as o}from"./index.85d1a54f.js";import{d as a,c as r,a5 as p,f as d,u as l,ea as f,h as c,o as i,_ as u}from"./jwt-decode.esm.611ae497.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="b7b49b04-269d-44ad-9427-056e589e29ba",e._sentryDebugIdIdentifier="sentry-dbid-b7b49b04-269d-44ad-9427-056e589e29ba")}catch{}})();const _=a({__name:"Steps",props:{stepsInfo:{},isPreview:{type:Boolean}},setup(e){const s=e,n=r(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",description:""})):[]);return(t,b)=>t.stepsInfo?(i(),p("nav",{key:0,class:f(["p-steps",{"full-screen":!t.isPreview}])},[d(l(o),{current:t.stepsInfo.current-1,items:n.value,responsive:!1},null,8,["current","items"])],2)):c("",!0)}});const I=u(_,[["__scopeId","data-v-58fdd395"]]);export{I as S};
//# sourceMappingURL=Steps.aa7e59b1.js.map
