import{d as a,o as t,a5 as o,f as s,u as _,S as c,_ as r}from"./jwt-decode.esm.611ae497.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="cdff8100-42b4-4a75-bcf7-2ea9add51cdd",e._sentryDebugIdIdentifier="sentry-dbid-cdff8100-42b4-4a75-bcf7-2ea9add51cdd")}catch{}})();const f={class:"centered"},i=a({__name:"LoadingContainer",setup(e){return(n,d)=>(t(),o("div",f,[s(_(c))]))}});const u=r(i,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.5d37f646.js.map
